@@ -20,13 +20,12 @@ class HealthCertificateManager : public QAbstractListModel
     Q_PROPERTY(bool isAvailable READ isAvailable CONSTANT)
 public:
     explicit HealthCertificateManager(QObject *parent = nullptr);
-    ~HealthCertificateManager();
+    ~HealthCertificateManager() override;
 
     /** Health certificate support is compiled in. */
     bool isAvailable() const;
 
-    void importCertificate(const QByteArray &rawData);
-    Q_INVOKABLE void importCertificateFromClipboard();
+    bool importCertificate(const QByteArray &rawData);
     Q_INVOKABLE void removeCertificate(int row);
 
     enum {
@@ -39,6 +38,9 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     QHash<int, QByteArray> roleNames() const override;
 
+Q_SIGNALS:
+    void newCertificateLoaded(int index);
+
 private:
     struct CertData {
         QString name;
