@@ -8,14 +8,15 @@
 
 #include "calendarhelper.h"
 #include "constants.h"
+#include "documentmanager.h"
 #include "livedatamanager.h"
 #include "locationhelper.h"
 #include "logging.h"
+#include "reservationhelper.h"
 #include "reservationmanager.h"
 #include "publictransport.h"
 #include "transfer.h"
 #include "transfermanager.h"
-#include "documentmanager.h"
 
 #include <KItinerary/BusTrip>
 #include <KItinerary/CalendarHandler>
@@ -405,7 +406,7 @@ static bool isJourneyCandidate(const QVariant &res)
 
 static bool isLayover(const QVariant &res1, const QVariant &res2)
 {
-    if (!LocationUtil::isLocationChange(res1) || !LocationUtil::isLocationChange(res2)) {
+    if (!LocationUtil::isLocationChange(res1) || !LocationUtil::isLocationChange(res2) || ReservationHelper::isUnbound(res1) || ReservationHelper::isUnbound(res2)) {
         return false;
     }
 
@@ -590,6 +591,15 @@ bool TimelineDelegateController::isCanceled() const
     return JsonLd::convert<Reservation>(res).reservationStatus() == Reservation::ReservationCancelled;
 }
 
+static void mapArgumentsForLocation(QJSValue &args, const QVariant &location, QJSEngine *engine)
+{
+    args.setProperty(QStringLiteral("placeName"), LocationUtil::name(location));
+    args.setProperty(QStringLiteral("region"), LocationHelper::regionCode(location));
+
+    const auto geo = LocationUtil::geo(location);
+    args.setProperty(QStringLiteral("coordinate"), engine->toScriptValue(QPointF(geo.longitude(), geo.latitude())));
+}
+
 static void mapArgumentsForPt(QJSValue &args, QLatin1String prefix, const KPublicTransport::Stopover &stop)
 {
     const auto platformName = stop.hasExpectedPlatform() ? stop.expectedPlatform() : stop.scheduledPlatform();
@@ -650,9 +660,7 @@ QJSValue TimelineDelegateController::arrivalMapArguments() const
     }
 
     auto args = engine->newObject();
-    const auto arrLoc = LocationUtil::arrivalLocation(res);
-    args.setProperty(QStringLiteral("placeName"), LocationUtil::name(arrLoc));
-    args.setProperty(QStringLiteral("region"), LocationHelper::regionCode(arrLoc));
+    mapArgumentsForLocation(args, LocationUtil::arrivalLocation(res), engine);
 
     // arrival location
     mapArrivalArgumesForRes(args, res);
@@ -710,9 +718,7 @@ QJSValue TimelineDelegateController::departureMapArguments() const
     }
 
     auto args = engine->newObject();
-    const auto depLoc = LocationUtil::departureLocation(res);
-    args.setProperty(QStringLiteral("placeName"), LocationUtil::name(depLoc));
-    args.setProperty(QStringLiteral("region"), LocationHelper::regionCode(depLoc));
+    mapArgumentsForLocation(args, LocationUtil::departureLocation(res), engine);
 
     // departure location
     mapDepartureArgumentsForRes(args, res);
@@ -757,6 +763,84 @@ QJSValue TimelineDelegateController::departureMapArguments() const
     return args;
 }
 
+QJSValue TimelineDelegateController::mapArguments() const
+{
+    const auto engine = qjsEngine(this);
+    if (!engine || !m_resMgr || m_batchId.isEmpty() || !m_transferMgr || !m_liveDataMgr) {
+        return {};
+    }
+
+    const auto res = m_resMgr->reservation(m_batchId);
+    if (LocationUtil::isLocationChange(res)) {
+        return {};
+    }
+
+    auto args = engine->newObject();
+    mapArgumentsForLocation(args, LocationUtil::location(res), engine);
+
+    // determine time on site, considering the following sources:
+    // (1) the full days res is covering
+    // (2) arrival time of a preceding location change, departure time of a following location change
+    // (3) arrival time of a preceding transfer, departure time of a following transfer
+
+    auto beginDt = SortUtil::startDateTime(res);
+    beginDt.setTime({});
+
+    for (auto prevResId = m_resMgr->previousBatch(m_batchId); !prevResId.isEmpty(); prevResId = m_resMgr->previousBatch(prevResId)) {
+        const auto prevRes = m_resMgr->reservation(prevResId);
+        if (LocationUtil::isLocationChange(prevRes)) {
+            beginDt = std::max(SortUtil::endDateTime(prevRes), beginDt);
+            break;
+        }
+    }
+
+    auto transfer = m_transferMgr->transfer(m_batchId, Transfer::Before);
+    if (transfer.state() == Transfer::Selected) {
+        const auto arr = PublicTransport::lastTransportSection(transfer.journey()).arrival();
+        mapArgumentsForPt(args, QLatin1String("arrival"), arr);
+        beginDt = std::max(arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime(), beginDt);
+    }
+
+    args.setProperty(QStringLiteral("beginTime"), engine->toScriptValue(beginDt));
+
+    auto endDt = SortUtil::endDateTime(res);
+    if (endDt.isValid()) {
+        endDt = endDt.addDays(1);
+        endDt.setTime({});
+    }
+
+    transfer = m_transferMgr->transfer(m_batchId, Transfer::After);
+    if (transfer.state() == Transfer::Selected) {
+        const auto dep = PublicTransport::firstTransportSection(transfer.journey()).departure();
+        mapArgumentsForPt(args, QLatin1String("departure"), dep);
+        const auto depDt = dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime();
+        endDt = endDt.isValid() ? std::min(endDt, depDt) : depDt;
+    }
+
+    // search the first location change after the end (which might not always be the next element)
+    const auto dt = SortUtil::endDateTime(res);
+    auto nextResId = m_resMgr->nextBatch(m_batchId);
+    auto nextRes = m_resMgr->reservation(nextResId);
+    while (dt.isValid() && SortUtil::startDateTime(nextRes).date() <= dt.date()) {
+        if (LocationUtil::isLocationChange(nextRes)) {
+            const auto depDt = SortUtil::startDateTime(nextRes);
+            if (depDt.isValid() && depDt >= SortUtil::endDateTime((res))) {
+                endDt = endDt.isValid() ? std::min(depDt, endDt) : depDt;
+                break;
+            }
+        }
+
+        nextResId = m_resMgr->nextBatch(nextResId);
+        nextRes = m_resMgr->reservation(nextResId);
+    }
+
+    if (endDt.isValid()) {
+        args.setProperty(QStringLiteral("endTime"), engine->toScriptValue(endDt));
+    }
+
+    return args;
+}
+
 int TimelineDelegateController::documentCount() const
 {
     if (!m_resMgr || m_batchId.isEmpty()) {
